@@ -351,8 +351,8 @@ class SPEIT(InjectionAttack):
         for i in range(n_epoch):
             features_concat = torch.cat((features, features_attack), dim=0)
             pred = model(features_concat, adj_attacked_tensor)
-            pred_loss = -F.nll_loss(pred[:n_total][target_mask],
-                                    origin_labels[target_mask]).to(self.device)
+            pred_loss = -self.loss(pred[:n_total][target_mask],
+                                   origin_labels[target_mask]).to(self.device)
             optimizer.zero_grad()
             pred_loss.backward(retain_graph=True)
             optimizer.step()
